@@ -2,26 +2,10 @@
 
 import json
 import pika
-import time
 from pika.exchange_type import ExchangeType
 
 RETRY_COUNT = 5
 
-def retry(func):
-
-    def __wrapper__(*args, **kwarges):
-        count = RETRY_COUNT
-        while count>0:
-            res = func(*args, **kwarges)
-            if res:
-                break
-
-            count -=1
-            print('reconnect channel')
-            time.sleep(3)
-        return res
-    return __wrapper__
-
 
 class Puber(object):
 
@@ -64,10 +48,13 @@ class Puber(object):
                     routing_key=self._routing_key,
                     body=data,
                     properties=pika.BasicProperties(content_type=content_type))
-                break
+                return True
             except Exception as e:
-                self.recreate_channel()
-                print(e)
+                if i == RETRY_COUNT-1:
+                    raise e
+                else:
+                    self.recreate_channel()
+                    print(e)
 
     def recreate_channel(self):
         self.connect()
